@@ -18,17 +18,22 @@ Example:
   # This is equivalent to `ledger bal income expenses`
   python ledger_to_bql.py income expenses
 
+  # Translate a command to show a grand total row.
+  # This is equivalent to `ledger bal --total`
+  python ledger_to_bql.py --total
+
 Key Mappings:
   - `--depth X` or `-d X` -> `GROUP BY level(account) <= X`
   - `--zero` or `-Z`       -> `WHERE balance != 0` (removes accounts with zero balance)
   - `--begin DATE` or `-b DATE` -> `WHERE date >= "DATE"`
   - `--end DATE` or `-e DATE`   -> `WHERE date < "DATE"`
+  - `--total` or `-T`           -> Show a grand total row at the end
   - `ACCOUNT_REGEX`           -> `WHERE account ~ "ACCOUNT_REGEX"`
   - `@DESCRIPTION_REGEX   -> `WHERE description ~ "DESCRIPTION_REGEX"`
 """
 
 import argparse
-from .date_parser import parse_date
+from .date_parser import parse_date, parse_date_range
 from .utils import add_common_arguments, execute_bql_command, parse_amount_filter
 
 
@@ -45,7 +50,7 @@ def create_parser():
     add_common_arguments(parser)
 
     parser.add_argument(
-        '--depth', '-d',
+        '--depth', '-D',
         type=int,
         help="Show accounts up to a certain depth (level) in the account tree."
     )
@@ -83,6 +88,14 @@ def parse_query(args):
     if args.end:
         end_date = parse_date(args.end)
         where_clauses.append(f'date < date("{end_date}")')
+    
+    # Handle date range if provided
+    if args.date_range:
+        begin_date, end_date = parse_date_range(args.date_range)
+        if begin_date:
+            where_clauses.append(f'date >= date("{begin_date}")')
+        if end_date:
+            where_clauses.append(f'date < date("{end_date}")')
 
     # Handle amount filters
     if args.amount:
@@ -92,6 +105,14 @@ def parse_query(args):
             if cur:
                 amount_clause += f" AND currency = '{cur}'"
             where_clauses.append(amount_clause)
+    
+    # Handle currency filter
+    if args.currency:
+        if isinstance(args.currency, list):
+            currencies_str = "', '".join(args.currency)
+            where_clauses.append(f"currency IN ('{currencies_str}')")
+        else:
+            where_clauses.append(f"currency = '{args.currency}'")
 
     # Build the final query
     select_clause = "SELECT account, units(sum(position)) as Balance"
@@ -124,6 +145,10 @@ def parse_query(args):
 def format_output(output: list, args) -> list:
     """Formats the raw output from the BQL query into a pretty-printable list."""
     formatted_output = []
+    
+    # Initialize grand total dictionary to accumulate balances by currency
+    grand_total = {}
+    
     for row in list(output): # Ensure output is a list of lists
         if not row:
             continue
@@ -141,7 +166,7 @@ def format_output(output: list, args) -> list:
         
         # An Inventory object can contain multiple currencies. We need to iterate
         # through its items, which are (currency, Position) pairs.
-        formatted_balance = ""
+        balance_parts = []
         for currency, amount in balance_inventory.items():
             # Check if the currency is a tuple and extract the string
             if isinstance(currency, tuple):
@@ -152,12 +177,34 @@ def format_output(output: list, args) -> list:
             # Correctly access the number from the Position object's `units`
             formatted_value = "{:,.2f}".format(amount.units.number)
             
-            formatted_balance += f"{formatted_value} {currency_str}"
+            balance_parts.append(f"{formatted_value} {currency_str}")
+            
+            # Accumulate for grand total
+            if args.total:
+                if currency_str in grand_total:
+                    grand_total[currency_str] += amount.units.number
+                else:
+                    grand_total[currency_str] = amount.units.number
+        
+        formatted_balance = " ".join(balance_parts)
         
         new_row = list(row)
         new_row[-1] = formatted_balance
         formatted_output.append(tuple(new_row))
 
+    # Add grand total row if requested
+    if args.total and grand_total:
+        # Format the grand total balances
+        total_parts = []
+        for currency, amount in grand_total.items():
+            formatted_value = "{:,.2f}".format(amount)
+            total_parts.append(f"{formatted_value} {currency}")
+        
+        formatted_total = " ".join(total_parts)
+        # Add a separator row and the total row
+        formatted_output.append(("-------------------", "-------------------"))
+        formatted_output.append(("Total", formatted_total))
+
     return formatted_output
 
 
@@ -169,7 +216,7 @@ def main():
     
     # Pass args.depth to format_output_func via kwargs
     execute_bql_command(create_parser, parse_query, format_output, 
-                        headers, alignments)
+                        headers, alignments, command_type='bal')
 
 
 if __name__ == '__main__':
