@@ -4,6 +4,7 @@ Shared utilities.
 import argparse
 import os
 import re
+import sys
 from decimal import Decimal
 import beanquery
 from tabulate import tabulate
@@ -34,6 +35,10 @@ def add_common_arguments(parser):
         '--end', '-e',
         help='End date for the query (YYYY-MM-DD).'
     )
+    parser.add_argument(
+        '--date-range', '-d',
+        help='Date range in format YYYY..YYYY, YYYY-MM..YYYY-MM, or YYYY-MM-DD..YYYY-MM-DD'
+    )
     parser.add_argument(
         '--empty',
         # '-e',
@@ -56,6 +61,16 @@ def add_common_arguments(parser):
         action='append',
         help='Filter by amount. Format: [>|>=|<|<=|=]AMOUNT[CURRENCY]. E.g. >100EUR'
     )
+    parser.add_argument(
+        '--currency', '-c',
+        type=lambda x: [currency.upper() for currency in x.split(',')] if x and ',' in x else (x.upper() if x else None),
+        help='Filter by currency. E.g. EUR or EUR,BAM'
+    )
+    parser.add_argument(
+        '--total', '-T',
+        action='store_true',
+        help='Show a grand total row at the end of the balance report or a running total column in the register report.'
+    )
 
 
 def run_bql_query(query: str, book: str) -> list:
@@ -93,7 +108,7 @@ def parse_amount_filter(amount_str):
 
 
 def execute_bql_command(create_parser_func, parse_query_func, format_output_func, 
-                        headers, alignments, **kwargs):
+                        headers, alignments, command_type=None, **kwargs):
     """
     Executes a BQL command by parsing arguments, constructing a query, running it, 
     and formatting output.
@@ -118,10 +133,11 @@ def execute_bql_command(create_parser_func, parse_query_func, format_output_func
         return
 
     # Print the BQL query
-    print(f"\nYour BQL query is:\n\n{query}\n")
+    print(f"\nYour BQL query is:\n{query}\n")
 
     # Determine headers and alignments for the table based on args
-    if hasattr(args, 'total') and args.total:
+    # For register command with --total, add a Running Total column
+    if hasattr(args, 'total') and args.total and command_type == 'reg':
         headers.append("Running Total")
         alignments.append("right")
 
